pub struct PyActorAddr { /* private fields */ }Trait Implementations
Sourceimpl Clone for PyActorAddr
impl Clone for PyActorAddr
Sourcefn clone(&self) -> PyActorAddr
fn clone(&self) -> PyActorAddr
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PyActorAddr
impl Debug for PyActorAddr
Sourceimpl From<&PyActorAddr> for ActorAddr
impl From<&PyActorAddr> for ActorAddr
Sourcefn from(actor_id: &PyActorAddr) -> Self
fn from(actor_id: &PyActorAddr) -> Self
Converts to this type from the input type.
Sourceimpl From<ActorAddr> for PyActorAddr
impl From<ActorAddr> for PyActorAddr
Sourceimpl From<PyActorAddr> for ActorAddr
impl From<PyActorAddr> for ActorAddr
Sourcefn from(val: PyActorAddr) -> Self
fn from(val: PyActorAddr) -> Self
Converts to this type from the input type.
Sourceimpl<'py> IntoPyObject<'py> for PyActorAddr
impl<'py> IntoPyObject<'py> for PyActorAddr
Sourcetype Target = PyActorAddr
type Target = PyActorAddr
The Python output type
Sourcetype Output = Bound<'py, <PyActorAddr as IntoPyObject<'py>>::Target>
type Output = Bound<'py, <PyActorAddr as IntoPyObject<'py>>::Target>
The smart pointer type to use. Read more
Sourcefn into_pyobject(
self,
py: Python<'py>,
) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
fn into_pyobject( self, py: Python<'py>, ) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
Performs the conversion.
Sourceimpl PyClass for PyActorAddr
impl PyClass for PyActorAddr
Sourceimpl PyClassImpl for PyActorAddr
impl PyClassImpl for PyActorAddr
Sourceconst IS_BASETYPE: bool = false
const IS_BASETYPE: bool = false
#[pyclass(subclass)]
Sourceconst IS_SUBCLASS: bool = false
const IS_SUBCLASS: bool = false
#[pyclass(extends=…)]
Sourceconst IS_MAPPING: bool = false
const IS_MAPPING: bool = false
#[pyclass(mapping)]
Sourceconst IS_SEQUENCE: bool = false
const IS_SEQUENCE: bool = false
#[pyclass(sequence)]
Sourceconst IS_IMMUTABLE_TYPE: bool = false
const IS_IMMUTABLE_TYPE: bool = false
#[pyclass(immutable_type)]
Sourceconst RAW_DOC: &'static CStr = c"\x00"
const RAW_DOC: &'static CStr = c"\x00"
Docstring for the class provided on the struct or enum. Read more
Sourceconst DOC: &'static CStr
const DOC: &'static CStr
Fully rendered class doc, including the
text_signature if a constructor is defined. Read moreSourcetype ThreadChecker = SendablePyClass<PyActorAddr>
type ThreadChecker = SendablePyClass<PyActorAddr>
This handles following two situations: Read more
type Inventory = Pyo3MethodsInventoryForPyActorAddr
Sourcetype PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::ImmutableChild
type PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::ImmutableChild
Immutable or mutable
Sourcetype BaseNativeType = PyAny
type BaseNativeType = PyAny
The closest native ancestor. This is
PyAny by default, and when you declare
#[pyclass(extends=PyDict)], it’s PyDict.fn items_iter() -> PyClassItemsIter
fn lazy_type_object() -> &'static LazyTypeObject<Self>
fn dict_offset() -> Option<isize>
fn weaklist_offset() -> Option<isize>
Sourceimpl PyClassNewTextSignature for PyActorAddr
impl PyClassNewTextSignature for PyActorAddr
const TEXT_SIGNATURE: &'static str = "(*, addr, proc_name, actor_name)"
Sourceimpl PyClass__eq__SlotFragment<PyActorAddr> for PyClassImplCollector<PyActorAddr>
impl PyClass__eq__SlotFragment<PyActorAddr> for PyClassImplCollector<PyActorAddr>
Sourceimpl<'a, 'holder, 'py> PyFunctionArgument<'a, 'holder, 'py, false> for &'holder PyActorAddr
impl<'a, 'holder, 'py> PyFunctionArgument<'a, 'holder, 'py, false> for &'holder PyActorAddr
Sourceimpl PyTypeInfo for PyActorAddr
impl PyTypeInfo for PyActorAddr
Sourcefn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
fn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
Returns the PyTypeObject instance for this type.
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
Returns the safe abstraction over the type object.
fn is_type_of(object: &Bound<'_, PyAny>) -> bool
fn is_type_of(object: &Bound<'_, PyAny>) -> bool
Checks if
object is an instance of this type or a subclass of this type.fn is_exact_type_of(object: &Bound<'_, PyAny>) -> bool
fn is_exact_type_of(object: &Bound<'_, PyAny>) -> bool
Checks if
object is an instance of this type.impl DerefToPyAny for PyActorAddr